@@ -84,7 +84,7 @@ mod tests {
     };
 
     fn setup_ditto() -> Result<Ditto, DittoError> {
-        let mut ditto = Ditto::builder()
+        let ditto = Ditto::builder()
             .with_temp_dir()
             .with_identity(|ditto_root| identity::OfflinePlayground::random(ditto_root))?
             .with_minimum_log_level(CLogLevel::Info)
