@@ -63,9 +63,11 @@ fn insert_merges_with_existing_content_if_specified_in_options() {
     let store = ditto.store();
     let collection = store.collection("test").unwrap();
     let custom_id = DocumentId::new(&"custom_id".to_string()).unwrap();
+    //@ditto/snippet-start insert
     let id1 = collection
         .insert(json!({"some": "value"}), Some(&custom_id), false)
         .unwrap();
+    //@ditto/snippet-end
     let id2 = collection
         .insert_with_strategy(
             json!({"another": "thing"}),
@@ -490,7 +492,7 @@ fn evict_remove_and_update_with_args() {
     assert_eq!(docs.len(), 3);
 
     let removed_ids = collection
-        .find_with_args("color == $args.color)", json!({"color": "yellow"}))
+        .find_with_args("color == $args.color", json!({"color": "yellow"}))
         .remove()
         .unwrap();
     assert_eq!(removed_ids.len(), 1);
@@ -500,11 +502,13 @@ fn evict_remove_and_update_with_args() {
         query_c_str: c!("make"),
         direction: ffi_sdk::QuerySortDirection::Descending,
     };
+    //@ditto/snippet-start evict
     let evicted_ids = collection
-        .find_with_args("$args.color == color)", json!({"color": "red"}))
+        .find_with_args("$args.color == color", json!({"color": "red"}))
         .sort(vec![sort_param])
         .evict()
         .unwrap();
+    //@ditto/snippet-end
     assert_eq!(evicted_ids.len(), 2);
     assert_eq!(evicted_ids[0], honda_id);
     assert_eq!(evicted_ids[1], ferrari_id);
